@@ -16,7 +16,7 @@ from urllib3.util.retry import Retry
 from tqdm import tqdm
 import ntpath
 
-__version__ = "1.2.2"
+__version__ = "1.2.3"
 CONFIG_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                            ".canvassyncer.json")
 MAX_DOWNLOAD_COUNT = 8
@@ -462,7 +462,7 @@ def run():
             if args.r:
                 return
         config = json.load(open(configPath, 'r', encoding='UTF-8'))
-        if args.y: config['y'] = args.y
+        config['y'] = args.y
         if args.proxy: config['proxies'] = args.proxy
         Syncer = CanvasSyncer(config)
         Syncer.sync()
@@ -473,6 +473,7 @@ def run():
         print(
             f"\nUnexpected Error: {e.__class__.__name__}. Please check your network and your token!"
         )
+        raise e
     except KeyboardInterrupt as e:
         if Syncer:
             Syncer.downloader.stop()
